@@ -12,9 +12,9 @@
 
 (macsyma-module matrix)
 
-(declare-top (special errrjfflag oneoff* ei* ej* *ech* *tri* *inv*
-		      mdl dosimp $detout vlist mul* top* *det* genvar $ratfac
-		      *mosesflag varlist header linind* $scalarmatrixp $sparse
+(declare-top (special errrjfflag *ech* *tri* *inv*
+		      mdl $detout vlist mul* top* *det* genvar $ratfac
+		      varlist header $scalarmatrixp $sparse
 		      $algebraic *rank* *mat*))
 
 (defmvar $detout nil)
@@ -38,13 +38,14 @@
 (defun mcx (x)
   (mapcar #'cdr x))			; MACSYMA to Matrix conversion
 
-(defun transpose (m)
-  (prog (b nn len)
-     (setq len (length (car m)) nn 1)
-     loop (when (> nn len) (return b)) 
-     (setq b (nconc b (ncons (nthcol m nn))))
-     (incf nn)
-     (go loop)))
+;; Transpose a list of lists ll. Example: ((1 2) (3 4)) --> ((1 3) (2 4)).
+
+(defun transpose (ll)
+  (let ((acc nil))
+    (while (car ll)
+      (push (mapcar #'car ll) acc)
+      (setq ll (mapcar #'cdr ll)))
+    (nreverse acc)))
 
 (defun nthcol (x nn)
   (if (or (null x) (> nn (length (car x))))
@@ -142,10 +143,15 @@
       (mapcar #'ratplus a b))) 
 
 (defmfun $determinant (mat)
-  (cond ((not (or (mbagp mat) ($matrixp mat))) (if ($scalarp mat) mat (list '(%determinant) mat)))
+  (cond ((not (or (mbagp mat) ($matrixp mat))) 
+         (if ($scalarp mat) mat (list '(%determinant) mat)))
 	(t (setq mat (check mat))
 	   (unless  (= (length mat) (length (cadr mat)))
-	     (merror (intl:gettext "determinant: matrix must be square; found ~M rows, ~M columns.") (length mat) (length (cadr mat))))
+             (merror 
+               (intl:gettext
+                 "determinant: matrix must be square; found ~M rows, ~M columns.")
+               (length (cdr mat))
+               (length (cdadr mat))))
            (cond ((not $ratmx) (det1 (mcx (cdr mat))))
 	         (t (newvarmat1 mat) (determinant1 (mcx (cdr mat))))))))
 
@@ -262,20 +268,6 @@
      (push (or d '(0 . 1)) row)
      (go loop2)))
 
-(defmfun $invertmx (k) 
-  (let ((*inv* t) *det* linind* top* mul* ($ratmx t) (ratmx $ratmx) $ratfac $sparse)
-    (cond ((atom k) ($nounify '$inverx) (list '(%inverx) k))
-	  (t (newvarmat1 (setq k (check k)))
-	     (setq k (invert1 (replist1 (mcx (cdr k)))))
-	     (setq k (cond ($detout `((mtimes)
-				      ((mexpt) ,(rdis (or *det* '(1 . 1))) -1)
-				      (($matrix) ,@(mxc (disreplist1 k)))))
-			   (t (cons '($matrix) (mxc (disreplist1 k))))))
-	     (cond ((and ratmx (not $detout))
-		    (fmapl1 #'(lambda (x) x) k))
-		   ((not ratmx) ($totaldisrep k))
-		   (t k))))))
-
 (defun diaginv (ax m)
   (setq ax (get-array-pointer ax))
   (cond ($detout (setq *det* 1)
@@ -292,23 +284,6 @@
 					(pquotient (car *det*) (car elm))) 1))
 		 (t (ratinvert elm))))))
 
-(defun invert1 (k) 
-  (prog (l r g i m n ei* ej* oneoff*) 
-     (setq l (length k) i 1) 
-     (cond ((= l (length (car k))) nil)
-	   (t(merror (intl:gettext "invert: matrix must be square; found ~M rows, ~M columns.") l (length (car k)))))
-     loop (cond ((null k) (go l1))) 
-     (setq r (car k)) 
-     (setq g (nconc g (list (nconc r (onen i l '(1 . 1) '(0 . 1)))))) 
-     (setq k (cdr k) i (1+ i)) 
-     (go loop) 
-     l1   (setq k g)
-     (mtoa '*mat* (setq m (length k)) (setq n (length (car k))) k)
-     (setq k nil)
-     (cond ((diagp '*mat* m) (diaginv '*mat* m)) (t (tfgeli0 '*mat* m n)))
-     (setq k (atomat '*mat* m n (1+ m)))
-     (return k)))
-
 (defun diagp (ax m)
   (declare (fixnum m))
   (prog ((i 0) (j 0))
@@ -535,7 +510,7 @@
 	    (return (list '(mncexpt simp) mat x)))
 	   ((= x 1) (return mat))
 	   ((minusp x)
-	    (setq x (- x) mat ($invertmx mat))
+	    (setq x (- x) mat ($invert mat))
 	    (cond ($detout
 		   (return (let ((*inv* '$detout))
 			     (mul2* (power* (cadr mat) x)
