@@ -12,45 +12,6 @@
 (in-package :maxima)
 (macsyma-module mload)
 
-;; I decided to move most of the file hacking utilities I used in TRANSL to
-;; this file. -GJC
-
-;; Concepts:
-;; Lisp_level_filename. Anything taken by the built-in lisp I/O primitives.
-;;
-;; User_level_filename. Comes through the macsyma reader, so it has an extra "&"
-;;   in the pname in the case of "filename" or has extra "$" and has undergone
-;;   ALIAS transformation in the case of 'FOOBAR or '[FOO,BAR,BAZ].
-;;
-;; Canonical_filename. Can be passed to built-in lisp I/O primitives, and
-;;   can also be passed back to the user, is specially handled by the DISPLAY.
-;;
-;; Functions:
-;; $FILENAME_MERGE. Takes User_level_filename(s) and Canonical_filename(s) and
-;;   merges them together, returning a Canonical_filename.
-;;
-;; TO-MACSYMA-NAMESTRING. Converts a Lisp_level_filename to a Canonical_filename
-;;
-;; $FILE_SEARCH ............ Takes a user or canonical filename and a list of types of
-;;                           applicable files to look for.
-;; $FILE_TYPE   ............. Takes a user or canonical filename and returns
-;;                            NIL, $MACSYMA, $LISP, or $FASL.
-;; CALL-BATCH1 ............. takes a canonical filename and a no-echop flag.
-
-;;------
-;;There is also this problem of what file searching and defaulting means,
-;; especially when this is done across systems.  My feeling right now
-;; is that searching might actually be three-layered:
-;; host, device/directory, type [assuming a name is given].  This will become
-;; important in the near future because NIL is going to be supporting
-;; multiple hosts over DECNET, using the common-lisp/lispm model of pathnames
-;; and hosts.  One of the problems with incremental merging algorithms like
-;; are used here is that making a pathname the first time tends to force an
-;; interpretation with respect to some specific host, which is probably
-;; defaulted from some place used for ultimate defaulting and not normally
-;; used by higher-level facilities like LOAD.  --gsb
-;;------
-
 (declare-top (special $file_search_lisp $file_search_maxima $file_search_demo $loadprint))
 
 (defmfun load-and-tell (filename)
@@ -91,7 +52,7 @@
 (defun $batchload (filename &aux expr (*mread-prompt* ""))
   (declare (special *mread-prompt* *prompt-on-read-hang*))
   (setq filename ($file_search1 filename '((mlist) $file_search_maxima)))
-  (let (($load_pathname filename))
+  (let (($load_pathname filename) (noevalargs nil) (*read-base* 10.))
     (with-open-file (in-stream filename)
       (when $loadprint
 	(format t (intl:gettext "~&read and interpret file: ~A~&") (cl:namestring (truename in-stream))))
@@ -195,11 +156,12 @@
   (cond ((eq demo :test)
 	 (test-batch filename nil :show-all t))
 	(t
-	 (with-open-file (in-stream filename)
-	   (format t (intl:gettext "~%read and interpret file: ~A~%")
-		   (truename in-stream))
-	   (catch 'macsyma-quit (continue in-stream demo))
-	   (namestring in-stream)))))
+	 (let (($load_pathname filename) (*read-base* 10.))
+	   (with-open-file (in-stream filename)
+	     (format t (intl:gettext "~%read and interpret file: ~A~%")
+		     (truename in-stream))
+	     (catch 'macsyma-quit (continue in-stream demo))
+	     (namestring in-stream))))))
 
 ;; Return true if $float converts both a and b to floats and 
 
@@ -307,7 +269,8 @@
 			    (show-all nil) (showtime nil))
 
   (let ((result) (next-result) (next) (error-log) (all-differences nil) ($ratprint nil) (strm)
-	(*mread-prompt* "") (expr) (num-problems 0) (tmp-output) (save-output) (i 0)
+	(*mread-prompt* "") (*read-base* 10.)
+	(expr) (num-problems 0) (tmp-output) (save-output) (i 0)
 	(start-run-time 0) (end-run-time 0)
 	(start-real-time 0) (end-real-time 0)
 	(test-start-run-time 0) (test-end-run-time 0)
@@ -537,13 +500,14 @@
 		     ;; the original order.  Fortunately, this doesn't
 		     ;; have to be very fast, so we do it very naively.
 		     (dolist (test (mapcar #'remove-dollarsign (cdr tests)))
-		       (when (find test (cdr $testsuite_files)
-				   :key #'(lambda (x)
-					    (maxima-string (if (listp x)
-							       (second x)
-							       x)))
-				   :test #'string=)
-			 (push test results)))
+		       (let ((matching-test (find test (cdr $testsuite_files)
+						  :key #'(lambda (x)
+							   (maxima-string (if (listp x)
+									      (second x)
+									      x)))
+						  :test #'string=)))
+			 (when matching-test
+			   (push matching-test results))))
 		     (nreverse results)))
 		  (t
 		   (cdr $testsuite_files))))))
@@ -562,10 +526,11 @@
     
     (setq *collect-errors* nil)
     (unless $testsuite_files
-      (load (concatenate 'string *maxima-testsdir* "/" "testsuite.lisp")))
+      (let ((*read-base* 10.)) (load (concatenate 'string *maxima-testsdir* "/" "testsuite.lisp"))))
     (let ((error-break-file)
 	  (testresult)
-	  (tests-to-run (intersect-tests tests))
+	  (tests-to-run (intersect-tests (cond ((consp tests) tests)
+					       (tests (list '(mlist) tests)))))
 	  (test-count 0)
 	  (total-count 0)
 	  (error-count 0))
