@@ -171,7 +171,7 @@
 
 (defun hypertrigint1 (exp var hyperfunc)
   (let ((result (if hyperfunc
-                    (integrator (resimplify exp) var)
+                    (sinint (resimplify exp) var)
                     (rischint (resimplify exp) var))))
     ;; The result can contain solveable integrals. Look for this case.
     (if (isinop result '%integrate)
@@ -366,9 +366,11 @@
 (defun getfncoeff (a form)
   (cond ((null a) 0)
 	((equal (car a) 0) (getfncoeff (cdr a) form))
-	((eq (caaar a) 'mplus) (ratpl (getfncoeff (cdar a) form)
-				      (getfncoeff (cdr a) form)))
-	((eq (caaar a) 'mtimes)
+	((and (listp (car a))
+	      (eq (caaar a) 'mplus) (ratpl (getfncoeff (cdar a) form)
+					   (getfncoeff (cdr a) form))))
+	((and (listp (car a))
+	      (eq (caaar a) 'mtimes))
 	 (destructuring-let (((coef . newfn) (getfnsplit (cdar a))))
            ;; (car a) is a mtimes expression. We insert coef and newfn as the
            ;; new arguments to the mtimes expression. This causes problems if
@@ -1061,14 +1063,19 @@
     (putprop e (cdr d) 'rischdiff)
     (putprop e (cdr c) 'rischarg)))
 
+;; order of expressions for risch.
+;; expressions containing erf and li last.
+;; then order by size of expression to guarantee that
+;; any subexpressions are considered smaller.
+;; this relation should be transitive, since it is called by sort. 
 (defun intgreat (a b)
   (cond ((and (not (atom a)) (not (atom b)))
 	 (cond ((and (not (freeof '%erf a)) (freeof '%erf b)) t)
 	       ((and (not (freeof '$li a)) (freeof '$li b)) t)
 	       ((and (freeof '$li a) (not (freeof '$li b))) nil)
 	       ((and (freeof '%erf a) (not (freeof '%erf b))) nil)
-	       ((not (free b a)) nil)
-	       ((not (free a b)) t)
+	       ((> (conssize a) (conssize b)) t)
+	       ((< (conssize a) (conssize b)) nil)
 	       (t (great (resimplify (fixintgreat a))
 			 (resimplify (fixintgreat b))))))
 	(t (great (resimplify (fixintgreat a))
